Learn R Programming

BayesChange (version 2.3.0)

ClustCpObj: ClustCpObj class constructor

Description

A constructor for the ClustCpObj class, which stores the output of the change point detection and clustering algorithms.

Usage

ClustCpObj(
  data = NULL,
  n_iterations = NULL,
  n_burnin = NULL,
  clust = NULL,
  orders = NULL,
  time = NULL,
  norm_vec = NULL,
  entropy_MCMC = NULL,
  lkl_MCMC = NULL,
  I0_MCMC = NULL,
  kernel_ts = NULL,
  kernel_epi = NULL,
  univariate_ts = NULL
)

Value

An object of class ClustCpObj.

Arguments

data

A vector or matrix containing the observed data.

n_iterations

Total number of MCMC iterations.

n_burnin

Number of burn-in iterations removed from posterior summaries.

clust

A matrix where each row contains the cluster assignments for one iteration.

orders

A multidimensional array where each slice is a matrix representing the latent order at each iteration.

time

Total computational time (in seconds).

norm_vec

A vector containing precomputed normalization constants.

entropy_MCMC

A coda::mcmc object containing the MCMC samples of the entropy.

lkl_MCMC

A coda::mcmc object containing the log-likelihood values at each iteration.

I0_MCMC

A coda::mcmc object with the MCMC trace of the initial infection proportion \(I_0\).

kernel_ts

Logical; TRUE if the kernel corresponds to time-series data.

kernel_epi

Logical; TRUE if the kernel corresponds to epidemic diffusion data.

univariate_ts

Logical; TRUE if the data represent a univariate time series, FALSE for multivariate time series.