Learn R Programming

BayesChange (version 2.3.0)

DetectCpObj: DetectCpObj class constructor

Description

Constructor for the DetectCpObj class. This class stores the output of the Bayesian change–point detection algorithm, including MCMC traces, allocation orders, and computational information.

Usage

DetectCpObj(
  data = NULL,
  n_iterations = NULL,
  n_burnin = NULL,
  orders = NULL,
  time = NULL,
  entropy_MCMC = NULL,
  lkl_MCMC = NULL,
  phi_MCMC = NULL,
  sigma_MCMC = NULL,
  delta_MCMC = NULL,
  I0_MCMC = NULL,
  kernel_ts = NULL,
  kernel_epi = NULL,
  univariate_ts = NULL
)

Arguments

data

A vector or matrix containing the observed time series.

n_iterations

Total number of MCMC iterations.

n_burnin

Number of burn-in iterations to discard.

orders

A matrix where each row corresponds to the latent block assignment (order) of the time indices at each MCMC iteration.

time

Computational time in seconds.

entropy_MCMC

A coda::mcmc object containing MCMC samples of the entropy measure.

lkl_MCMC

A coda::mcmc object containing MCMC samples of the log-likelihood.

phi_MCMC

A coda::mcmc object containing MCMC draws for \(\gamma\).

sigma_MCMC

A coda::mcmc object containing MCMC draws for \(\sigma\).

delta_MCMC

A coda::mcmc object containing MCMC draws for \(\delta\).

I0_MCMC

A coda::mcmc object containing MCMC draws for \(I_0\).

kernel_ts

Logical; TRUE if the model for time series data is used.

kernel_epi

Logical; TRUE if the epidemic diffusion model is used.

univariate_ts

Logical; TRUE if the time series is univariate, FALSE otherwise.