Detect Change Points on a epidemic diffusion
detect_cp_epi(
data,
n_iterations,
q,
M,
xi,
a0,
b0,
I0_var = 0.01,
print_progress = TRUE,
user_seed = 1234L
)Function detect_cp_epi returns a list containing the following components:
$orders a matrix where each row corresponds to the output order of the corresponding iteration.
time computational time in seconds.
$I0_MCMC traceplot for \(I_0\).
a matrix where each column is a component of the epidemic diffusion and the rows correspond to the times.
number of MCMC iterations.
probability of performing a split at each iteration.
number of Monte Carlo iterations when computing the likelihood of the epidemic diffusion.
recovery rate fixed constant for each population at each time.
parameters for the computation of the integrated likelihood of the epidemic_diffusions.
variance for the Metropolis-Hastings estimation of the proportion of infected at time 0.
If TRUE (default) print the progress bar.
seed for random distribution generation.