Learn R Programming

BayesChange (version 2.3.0)

detect_cp_multi: Detect Change Points on multivariate time series

Description

Detect Change Points on multivariate time series

Usage

detect_cp_multi(
  data,
  n_iterations,
  q,
  k_0,
  nu_0,
  S_0,
  m_0,
  prior_delta_c = 1,
  prior_delta_d = 1,
  prior_var_phi = 0.1,
  print_progress = TRUE,
  user_seed = 1234L
)

Value

Function detect_cp_multi returns a list containing the following components:

  • $orders a matrix where each row corresponds to the output order of the corresponding iteration.

  • time computational time in seconds.

  • $phi_MCMC traceplot for \(\gamma\).

  • $sigma_MCMC traceplot for \(\sigma\).

  • $delta_MCMC traceplot for \(\delta\).

Arguments

data

a matrix where each row is a component of the time series and the columns correpospond to the times.

n_iterations

number of MCMC iterations.

q

probability of performing a split at each iteration.

k_0, nu_0, S_0, m_0

parameters for the Normal-Inverse-Wishart prior for \((\mu,\lambda)\).

prior_delta_c, prior_delta_d

parameters for the shifted Gamma prior for \(\delta\).

prior_var_phi

parameters for the correlation coefficient in the likelihood.

print_progress

If TRUE (default) print the progress bar.

user_seed

seed for random distribution generation.