Learn R Programming

BayesChange (version 2.3.0)

stock_uni: Daily Stock Price Dataset (Univariate Mean Series)

Description

This dataset contains detrended and standardized daily mean stock prices for the 50 largest companies (by market capitalization) in the S&P 500 index. Data cover the period from January 1, 2020 to January 1, 2022.

Usage

data(stock_uni)

Arguments

Format

A numeric matrix with 50 rows and 505 columns:

Rows

Companies (S&P 500 top 50)

Columns

Daily mean prices (505 observations)

Details

For each company, the mean price is computed as the average between the daily high and low prices. Each resulting time series contains 505 daily observations.