Perform change points detection on univariate and multivariate time series according to the methods presented by Asael Fabian Martínez and Ramsés H. Mena (2014) tools:::Rd_expr_doi("10.1214/14-BA878") and Corradin, Danese and Ongaro (2022) tools:::Rd_expr_doi("10.1016/j.ijar.2021.12.019"). It also clusters different types of time dependent data with common change points, see "Model-based clustering of time-dependent observations with common structural changes" (Corradin,Danese,KhudaBukhsh and Ongaro, 2024) tools:::Rd_expr_doi("10.48550/arXiv.2410.09552") for details.
Maintainer: Luca Danese l.danese1@campus.unimib.it (ORCID) [copyright holder]
Authors:
Riccardo Corradin
Andrea Ongaro
Useful links: