A constructor for the ClustCpObj class, which stores the output of
the change point detection and clustering algorithms.
ClustCpObj(
data = NULL,
n_iterations = NULL,
n_burnin = NULL,
clust = NULL,
orders = NULL,
time = NULL,
norm_vec = NULL,
entropy_MCMC = NULL,
lkl_MCMC = NULL,
I0_MCMC = NULL,
kernel_ts = NULL,
kernel_epi = NULL,
univariate_ts = NULL
)An object of class ClustCpObj.
A vector or matrix containing the observed data.
Total number of MCMC iterations.
Number of burn-in iterations removed from posterior summaries.
A matrix where each row contains the cluster assignments for one iteration.
A multidimensional array where each slice is a matrix representing the latent order at each iteration.
Total computational time (in seconds).
A vector containing precomputed normalization constants.
A coda::mcmc object containing the MCMC samples of the entropy.
A coda::mcmc object containing the log-likelihood values at each iteration.
A coda::mcmc object with the MCMC trace of the initial infection proportion \(I_0\).
Logical; TRUE if the kernel corresponds to time-series data.
Logical; TRUE if the kernel corresponds to epidemic diffusion data.
Logical; TRUE if the data represent a univariate time series, FALSE for multivariate time series.