Constructor for the DetectCpObj class. This class stores the output
of the Bayesian change–point detection algorithm, including MCMC traces,
allocation orders, and computational information.
DetectCpObj(
data = NULL,
n_iterations = NULL,
n_burnin = NULL,
orders = NULL,
time = NULL,
entropy_MCMC = NULL,
lkl_MCMC = NULL,
phi_MCMC = NULL,
sigma_MCMC = NULL,
delta_MCMC = NULL,
I0_MCMC = NULL,
kernel_ts = NULL,
kernel_epi = NULL,
univariate_ts = NULL
)A vector or matrix containing the observed time series.
Total number of MCMC iterations.
Number of burn-in iterations to discard.
A matrix where each row corresponds to the latent block assignment (order) of the time indices at each MCMC iteration.
Computational time in seconds.
A coda::mcmc object containing MCMC samples of the entropy measure.
A coda::mcmc object containing MCMC samples of the log-likelihood.
A coda::mcmc object containing MCMC draws for \(\gamma\).
A coda::mcmc object containing MCMC draws for \(\sigma\).
A coda::mcmc object containing MCMC draws for \(\delta\).
A coda::mcmc object containing MCMC draws for \(I_0\).
Logical; TRUE if the model for time series data is used.
Logical; TRUE if the epidemic diffusion model is used.
Logical; TRUE if the time series is univariate, FALSE otherwise.