Clustering univariate times series with common changes in time
clust_cp_uni(
data,
n_iterations,
B,
L,
phi,
a = 1,
b = 1,
c = 1,
q = 0.5,
alpha_SM = 0.1,
print_progress = TRUE,
user_seed = 1234L
)Function clust_cp_uni returns a list containing the following components:
$clust a matrix where each row corresponds to the output cluster of the corresponding iteration.
$orders a multidimensional array where each slice is a matrix and represent an iteration. The row of each matrix correspond the order associated to the corresponding cluster.
$time computational time in seconds.
$norm_vec a vector containing the normalisation constant computed at the beginning of the algorithm.
a matrix where each row is an observation and each column corresponds to a discrete time.
number of MCMC iterations.
number of orders for the normalisation constant.
number of split-merge steps for the proposal step.
parameters of the integrated likelihood.
probability of a split in the split-merge proposal and acceleration step.
\(\alpha\) for the main split-merge algorithm.
If TRUE (default) print the progress bar.
seed for random distribution generation.