Detect Change Points on multivariate time series
detect_cp_multi(
data,
n_iterations,
q,
k_0,
nu_0,
S_0,
m_0,
prior_delta_c = 1,
prior_delta_d = 1,
prior_var_phi = 0.1,
print_progress = TRUE,
user_seed = 1234L
)Function detect_cp_multi returns a list containing the following components:
$orders a matrix where each row corresponds to the output order of the corresponding iteration.
time computational time in seconds.
$phi_MCMC traceplot for \(\gamma\).
$sigma_MCMC traceplot for \(\sigma\).
$delta_MCMC traceplot for \(\delta\).
a matrix where each row is a component of the time series and the columns correpospond to the times.
number of MCMC iterations.
probability of performing a split at each iteration.
parameters for the Normal-Inverse-Wishart prior for \((\mu,\lambda)\).
parameters for the shifted Gamma prior for \(\delta\).
parameters for the correlation coefficient in the likelihood.
If TRUE (default) print the progress bar.
seed for random distribution generation.