A toy dataset generated from a stochastic SIR-type epidemic model using
the Doob–Gillespie algorithm. The transmission rate beta changes
once over time, resultiing in a single change-point in the infection
counts.
data(epi_synthetic)A 200 × 1 numeric matrix containing the daily number of infection events.
The simulation follows the stochastic simulation framework of: Anderson, D. F. and Kurtz, T. G. (2015). Stochastic Analysis of Biochemical Systems. Springer International Publishing.
The simulation uses:
S0 = 10000, I0 = 50
max_time = 200
A piecewise-constant transmission rate vector with a change at time 130
Infection event times aggregated using floor()